# SPDX-FileCopyrightText: 2008-2025 Luis Falcón <falcon@gnuhealth.org>
# SPDX-FileCopyrightText: 2011-2025 GNU Solidario <health@gnusolidario.org>
#
# SPDX-License-Identifier: GPL-3.0-or-later

from . import wizard_health_inpatient
from . import wizard_inpatient_evaluation


__all__ = ['wizard_health_inpatient', 'wizard_inpatient_evaluation']
